/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.geoviewer;

import com.vividsolutions.jts.geom.Geometry;
import javax.swing.Action;

/**
 * A DynamicGeometrical is a mutable Geometrical that defines extra 
 * methods for performing map actions.
 *
 * @author Wytse Visser
 */
public interface DynamicGeometrical<G extends Geometry> extends Geometrical<G> {
    
    /**
     * Update the geometry
     * 
     * @param geometry 
     */
    public void setGeometry(G geometry);
    
    /**
     * Creates and returns an array of actions that should be added to the
     * context menu of this DynamicGeometrical on the map, but not to the
     * default node actions.
     *
     * @return Map specific actions for this DynamicGeometrical
     */
    public Action[] getMapActions();

    /**
     * Adds the given map action to this DynamicGeometrical
     *
     * @param action The action to add
     */
    public void addMapAction(Action action);
}
