/*
 *  Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *           http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package nl.cloudfarming.client.geoviewer;

import nl.cloudfarming.client.geoviewer.event.GeoEvent;
import nl.cloudfarming.client.util.actions.OpenCloseHandler;
import nl.cloudfarming.eventbus.GuiEvent;
import nl.cloudfarming.eventbus.GuiEventKey;
import org.openide.nodes.Node;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
@ServiceProvider(service = OpenCloseHandler.class)
public class LayerObjectOpenCloseHandler implements OpenCloseHandler {

    @Override
    public void open(Node node) {
        if (node.getLookup().lookup(Layer.class) != null) {
            AddToMapEvent event = new AddToMapEvent(node);
            new GeoEvent.GeoEventProducer().triggerEvent(event);
        }
    }

    @Override
    public void close(Node node) {
        if (node.getLookup().lookup(Layer.class) != null) {
            RemoveFromMapEvent event = new RemoveFromMapEvent(node);
            new GeoEvent.GeoEventProducer().triggerEvent(event);            
        }
    }

    private class AddToMapEvent implements GuiEvent<Node> {

        private Node node;

        public AddToMapEvent(Node node) {
            this.node = node;
        }

        @Override
        public GuiEventKey getKey() {
            return GeoEvent.NEW_LAYER;
        }

        @Override
        public Node getContent() {
            return node;
        }
    }

    private class RemoveFromMapEvent implements GuiEvent<Node> {

        private Node node;

        public RemoveFromMapEvent(Node node) {
            this.node = node;
        }

        @Override
        public GuiEventKey getKey() {
            return GeoEvent.DISCARD_LAYER;
        }

        @Override
        public Node getContent() {
            return node;
        }
    }
}
