/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.geoviewer;

import java.awt.Color;
import java.util.Arrays;

/**
 * Palette for Legends
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
public abstract class LegendPalette<E> extends Palette<E> {

    public static final String PROP_LEGEND_COLORS = "legend_colors";

    public LegendPalette(Color baseColor) {
        super(baseColor);
    }

    public abstract LegendColors[] getColors();

    public abstract class LegendColors {

        public abstract Color getColor();

        public abstract String getDescription();

        @Override
        public final boolean equals(Object obj) {
            if (obj == null) {
                return false;
            }
            if (getClass() != obj.getClass()) {
                return false;
            }
            final LegendColors other = (LegendColors) obj;
            if (this.getColor() != null && other.getColor() != null) {
                if (!this.getColor().equals(other.getColor())) {
                    return false;
                }
            } else if (!(this.getColor() == null && other.getColor() == null)) {
                return false;
            }
            if (!this.getDescription().equals(other.getDescription())) {
                return false;
            }
            return true;
        }

        @Override
        public int hashCode() {
            int hash = 5;
            hash = 17 * hash + (this.getColor() != null ? this.getColor().hashCode() : 0);
            hash = 17 * hash + (this.getDescription() != null ? this.getDescription().hashCode() : 0);
            return hash;
        }
    }

    @Override
    public final boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final LegendPalette other = (LegendPalette) obj;
        if (!Arrays.equals(this.getColors(), other.getColors())) {
            return false;
        }
        return true;
    }

    @Override
    public final int hashCode() {
        int hash = 5;
        int colorHash = 0;
        if (this.getColors() != null) {
            for (LegendColors legensColor : this.getColors()) {
                colorHash += legensColor.hashCode();
            }
        }
        hash = 17 * hash + colorHash;
        return hash;
    }
}
