/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.geoviewer;

import nl.cloudfarming.client.geoviewer.event.GeoEvent;
import org.openide.awt.ActionID;
import org.openide.awt.ActionRegistration;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.NbBundle;
import org.openide.util.Utilities;
import org.openide.util.actions.NodeAction;

/**
 * <p>Action that can be enabled by placing {@link LayerListRemovableNode} in
 * the {@link  Utilities#actionsGlobalContext()}</p>
 *
 * <p>The {@link Node} which uses this action must implement {@link LayerListRemovableNode}</P>
 *
 * <p> Add the action to your context menu of your node by returning
 * SystemAction.get(RemoveLayerAction.class) in {@link Node#getActions(boolean)}
 * method </p>
 *
 * @author Timon Veenstra & Merijn Zengers
 */
@ActionID(category = "LayerAction",
id = "nl.cloudfarming.client.geoviewer.RemoveLayerAction")
@ActionRegistration(displayName = "#remove_layer.name")
@NbBundle.Messages({"remove_layer.name=Remove"})
//TODO: Should this still implement LayerAction it does not seem to be used anymore. If reinstated some refactorring is needed
public class RemoveLayerAction extends NodeAction {

    /**
     * Will trigger a {@link GeoEvent#DISCARD_LAYER} with parameter {@link LayerListRemovableNode#getRemovableNode()}
     * for every passed {@link Node}
     *
     * @param activatedNodes
     */
    @Override
    protected void performAction(Node[] activatedNodes) {
        for (Node node : activatedNodes) {
            if (node instanceof LayerListRemovableNode) {
                GeoEvent.getProducer().triggerEvent(GeoEvent.DISCARD_LAYER, ((LayerListRemovableNode) node).getRemovableNode());
            }
        }
    }

    /**
     * <p>Checks if this action can be enabled</p> Can only be enabled id and
     * only if all the passed nodes are of type{@link LayerListRemovableNode}
     *
     * @param activatedNodes
     * @return
     */
    //FIXME: Should only be enabled when LayerListRemovableNode 's are int the lookup. 
    //But The widgets on the map also contain nodes and because the layerlist and the map are one top component these are in the lookup as well.
    //Beacause of that is enabled if one of the activated nodes is a LayerListRemovableNode. 
    //This in the relative comfort of knowing only LayerListNode and Filternode from the map are available activatedNodes 
    @Override
    protected boolean enable(Node[] activatedNodes) {
        boolean enabled = false;
        for (Node node : activatedNodes) {
            if (node instanceof LayerListRemovableNode) {
                enabled = true;
                break;
            }
        }
        return enabled;
    }

    /**
     * Get the name of the action
     */
    @Override
    public String getName() {
        return Bundle.remove_layer_name();
    }

    /**
     * No help is provided
     *
     * @return
     */
    @Override
    public HelpCtx getHelpCtx() {
        return null;
    }
}
