/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer;

import com.vividsolutions.jts.geom.Geometry;
import java.io.IOException;
import org.netbeans.api.actions.Savable;
import org.openide.util.Exceptions;
import org.openide.util.Lookup;

/**
 * Layer containing a single geometrical object which can be edited.
 * 
 * @author johan
 */
public class SingleObjectLayer extends SimpleLayer {
    public static final String PROP_GEOMETRY = "geometry";
    private final DynamicGeometrical object;
    private final Lookup lookup;

    /**
     * 
     * @param name
     * @param geometrical the "single object" which provides the geometry for this layer
     * @param lookup optional lookup for autosave feature; this might need to come from a
     * different node than the one that provides the geometrical (e.g. for a treatment zone
     * the field would need to be saved)
     */
    public SingleObjectLayer(String name, DynamicGeometrical geometrical, Lookup lookup) {
        super(name);
        this.object = geometrical;
        this.lookup = lookup;
    }
    
    public SingleObjectLayer(String name, DynamicGeometrical geometrical, Lookup lookup, Palette palette) {
        this(name, geometrical, lookup);
        setPalette(palette);
    }
    
    public boolean hasGeometry() {
        return object.getGeometry() != null  && !object.getGeometry().isEmpty();
    }

    public Geometrical getObject() {
        return object;
    }
    
    public void setGeometry(Geometry newGeometry) {
        Geometry oldGeometry = object.getGeometry();
        object.setGeometry(newGeometry);
        // notify listeners, e.g. a layerpanel so it can create/update widgets
        getChangeSupport().firePropertyChange(PROP_GEOMETRY, oldGeometry, newGeometry);
        
        // autosave:
        if (lookup != null) {
            Savable savable = lookup.lookup(Savable.class);
            if (savable != null) {
                try {
                    savable.save();
                } catch (IOException ex) {
                    Exceptions.printStackTrace(ex);
                }
            }
        }
    }
    
}
